pkmn-colosseum decompilation progress · ByteMatchpkmn-colosseum is 15.54% decompiled
0.00% fully linked · GameCube
Code (2.50 MB)
Matched15.54% · 387,852 of 2,495,108 bytes (387.85 KB)Fuzzy match31.41% · ≈783,723 of 2,495,108 bytes (783.72 KB), counting partly matched code Fully linked 0.00%
Fully linked
0.00% · 0 of 2,495,108 bytes (0 B)
Matched 15.54%Matched15.54% · 387,852 of 2,495,108 bytes (387.85 KB)
Fuzzy match 31.41%Fuzzy match31.41% · ≈783,723 of 2,495,108 bytes (783.72 KB), counting partly matched code
Data (2.20 MB)
Matched0.77% · 16,933 of 2,196,256 bytes (16.93 KB) Fully linked 0.00%Fully linked0.00% · 0 of 2,196,256 bytes (0 B)Matched 0.77%Matched0.77% · 16,933 of 2,196,256 bytes (16.93 KB)
56734ae | README: progress update
· No unit breakdown is stored for this commit (it came from decomp.dev's history, which keeps totals only).
Merge pull request #664: verified 97.44 percent source data